int approx();
int ch2inv_();
int chol_();
int bkslv_();
int bincode();
int bincode2();
int bincount();
int cg_();
int ch_();
int cumsum();
int distance();
int dpoco_();
int dpodi_();
int dpofa_();
int dposl_();
int dqrcf_();
int dqrdc_();
int dqrdc2_();
int dqrls_();
int dqrsl_();
int dqrqty_();
int dqrqy_();
int dqrrsd_();
int dqrsl_();
int dqrxb_();
int dsvdc_();
int dtrsl_();
int fft_factor();
int fft_work();
int fmin_();
int lminfl_();
int lowess();
int massdist();
int optif9_();
int pretty();
int rg_();
int root1d_();
int rs_();
int spline_coef();
int spline_eval();
int stemleaf();
int str_signif();
int tabulate();
